pub struct DeviceData {
pub serial: String,
pub name: String,
pub is_connected: bool,
pub manufacturer: Option<String>,
pub product: Option<String>,
}Fields
serial: Stringname: Stringis_connected: boolmanufacturer: Option<String>product: Option<String>Trait Implementations
Sourceimpl Debug for DeviceData
impl Debug for DeviceData
Sourceimpl<'de> Deserialize<'de> for DeviceData
impl<'de> Deserialize<'de> for DeviceData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for DeviceData
impl Hash for DeviceData
Sourceimpl JsonSchema for DeviceData
impl JsonSchema for DeviceData
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeviceData
impl PartialEq for DeviceData
Sourceimpl Serialize for DeviceData
impl Serialize for DeviceData
impl StructuralPartialEq for DeviceData