pub struct LogRequest {
pub count: u32,
}Fields
count: u32Trait Implementations
Sourceimpl Debug for LogRequest
impl Debug for LogRequest
Sourceimpl<'de> Deserialize<'de> for LogRequest
impl<'de> Deserialize<'de> for LogRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for LogRequest
impl Hash for LogRequest
Sourceimpl JsonSchema for LogRequest
impl JsonSchema for LogRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LogRequest
impl PartialEq for LogRequest
Sourceimpl Serialize for LogRequest
impl Serialize for LogRequest
impl StructuralPartialEq for LogRequest