pub struct ProxyRequest {
pub path: String,
pub req_key: Key,
pub resp_key: Key,
pub seq_no: u32,
pub body: Value,
}Fields
path: Stringreq_key: Keyresp_key: Keyseq_no: u32body: ValueTrait Implementations
Sourceimpl Debug for ProxyRequest
impl Debug for ProxyRequest
Sourceimpl<'de> Deserialize<'de> for ProxyRequest
impl<'de> Deserialize<'de> for ProxyRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProxyRequest
impl JsonSchema for ProxyRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProxyRequest
impl PartialEq for ProxyRequest
Sourceimpl Serialize for ProxyRequest
impl Serialize for ProxyRequest
impl StructuralPartialEq for ProxyRequest