pub struct ProxyResponseOk {
pub resp_key: Key,
pub seq_no: u32,
pub body: Value,
}Fields
resp_key: Keyseq_no: u32body: ValueTrait Implementations
Sourceimpl Debug for ProxyResponseOk
impl Debug for ProxyResponseOk
Sourceimpl<'de> Deserialize<'de> for ProxyResponseOk
impl<'de> Deserialize<'de> for ProxyResponseOk
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProxyResponseOk
impl JsonSchema for ProxyResponseOk
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProxyResponseOk
impl PartialEq for ProxyResponseOk
Sourceimpl Serialize for ProxyResponseOk
impl Serialize for ProxyResponseOk
impl StructuralPartialEq for ProxyResponseOk