pub struct TopicStreamMsg {
pub stream_id: Uuid,
pub msg: Value,
}Fields
stream_id: Uuidmsg: ValueTrait Implementations
Sourceimpl Debug for TopicStreamMsg
impl Debug for TopicStreamMsg
Sourceimpl<'de> Deserialize<'de> for TopicStreamMsg
impl<'de> Deserialize<'de> for TopicStreamMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for TopicStreamMsg
impl Hash for TopicStreamMsg
Sourceimpl JsonSchema for TopicStreamMsg
impl JsonSchema for TopicStreamMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TopicStreamMsg
impl PartialEq for TopicStreamMsg
Sourceimpl Serialize for TopicStreamMsg
impl Serialize for TopicStreamMsg
impl StructuralPartialEq for TopicStreamMsg