pub struct TopicStreamRequest {
pub path: String,
pub key: Key,
}Fields
path: Stringkey: KeyTrait Implementations
Sourceimpl Debug for TopicStreamRequest
impl Debug for TopicStreamRequest
Sourceimpl<'de> Deserialize<'de> for TopicStreamRequest
impl<'de> Deserialize<'de> for TopicStreamRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for TopicStreamRequest
impl Hash for TopicStreamRequest
Sourceimpl JsonSchema for TopicStreamRequest
impl JsonSchema for TopicStreamRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TopicStreamRequest
impl PartialEq for TopicStreamRequest
Sourceimpl Serialize for TopicStreamRequest
impl Serialize for TopicStreamRequest
impl StructuralPartialEq for TopicStreamRequest